@@ -69,6 +69,7 @@ class BaseRustSocket:
         """
         try:
             self.ws.connect()
+            await self._send_wakeup_request()
         except ConnectionRefusedError:
             raise ServerNotResponsiveError("Cannot Connect")
 
@@ -84,6 +85,19 @@ class BaseRustSocket:
         Disconnects from the Rust Server
         """
         await self.close_connection()
+
+    async def _send_wakeup_request(self) -> None:
+        """
+        Sends a request to the server to wake up broadcast responses
+        """
+        await self._handle_ratelimit()
+
+        app_request = self._generate_protobuf()
+        app_request.checkSubscription.CopyFrom(AppEmpty())
+
+        self.ws.ignored_responses.append(app_request.seq)
+
+        await self.ws.send_message(app_request)
     
     def command(self, coro) -> None:
         """
@@ -93,7 +107,7 @@ class BaseRustSocket:
         if self.command_options is None:
             raise CommandsNotEnabledError("Not enabled")
 
-        self.ws.command_handler.registerCommand(coro.__name__, coro)
+        self.ws.command_handler.registerCommand(coro.__name__, coro, asyncio.get_event_loop())
 
     async def hang(self) -> None:
         """This Will permanently put your script into a state of 'hanging' Cannot be Undone. Only do this in scripts using commands"""
