@@ -2,12 +2,12 @@ class RustMap:
 
     def __init__(self, data) -> None:
         
-        self.width = data.width
-        self.height = data.height
-        self.jpgImage = data.jpgImage
-        self.margin = data.oceanMargin
+        self.width : int = data.width
+        self.height : int = data.height
+        self.jpgImage : float = data.jpgImage
+        self.margin : int = data.oceanMargin
         self.monuments = [RustMonument(monument.token, monument.x, monument.y) for monument in data.monuments]
-        self.background = None if data.background == "" else data.background
+        self.background : str = None if data.background == "" else data.background
 
     def __str__(self) -> str:
         return "RustMap[width={}, height={}, jpgImage={}, margin={}, monuments={}, background={}]".format(self.width, self.height, len(self.jpgImage), self.margin, self.monuments, self.background)
@@ -17,9 +17,9 @@ class RustMonument:
 
     def __init__(self, token, x, y) -> None:
         
-        self.token = token
-        self.x = x
-        self.y = y
+        self.token : str = token
+        self.x : float = x
+        self.y : float = y
 
     def __str__(self) -> str:
         return "RustMonument[token={}, x={}, y={}]"
\ No newline at end of file
